library( "stringr" )
library("nlme")
library("plyr")
options(stringsAsFactors=F)

# Sex, ethnicity and age differential gene expression analysis

model <- function(df){

df_t = as.data.frame(t(df))
gene_ID = colnames(df_t)
df_t$SRR_ID = rownames(df_t)
colnames(df_t)[1]="gene"
all=merge(info_I_need,df_t,by.x="sra_accession",by.y="SRR_ID")

model = tryCatch(lme(fixed = gene ~ SMTS + GENDER2 + AGE + RACE, random = ~1|Individual_ID, control=lmeControl(opt = "optim",maxIter=500000,msMaxIter=500000,na.action=na.omit),data = all), error=function(e) NULL)
if(!is.null(model))
{
	p_value_sex=summary(model)$tTable["GENDER2","p-value"]
	coeff_sex=summary(model)$tTable["GENDER2","Value"]
	p_value_age = summary(model)$tTable["AGE","p-value"]
	coeff_age = summary(model)$tTable["AGE","Value"]
	p_value_race = summary(model)$tTable["RACE","p-value"]
	coeff_race = summary(model)$tTable["RACE","Value"]
	result = data.frame(transcript_ID=gene_ID,coeff_sex=coeff_sex,p_value_sex=p_value_sex,coeff_age=coeff_age,p_value_age=p_value_age,coeff_race=coeff_race,p_value_race=p_value_race)
	
}else{
	result = data.frame(transcript_ID=gene_ID,coeff_sex=0,p_value_sex=NA,coeff_age=0,p_value_age=NA,coeff_race=0,p_value_race=NA)
}
	return(result)
}

#read file

info_I_need = read.table("SRA_ID_SMT_SUBJID_AGE_RACE_GENDER",header=T,sep="\t")
info_I_need$GENDER2 = info_I_need$GENDER
info_I_need[info_I_need$GENDER==2,"GENDER2"] = -1 #female:-1 male:1


args <- commandArgs(trailingOnly = TRUE)
header = read.table("header",sep="\t",header=F,check.names=F)
all_FPKM_tissue_individual = read.table(args[1],sep="\t",header=F,check.names=F)
colnames(all_FPKM_tissue_individual) = as.character(header[,])
rownames(all_FPKM_tissue_individual)=all_FPKM_tissue_individual$t_name

all_filter = all_FPKM_tissue_individual


all_filter = all_filter[,-1]
all_filter[all_filter<0.1] <- 0

all_filter_log=log(all_filter+1)

colnames(all_filter_log)=sub(":.*", "",colnames(all_filter_log))

#call the function

all_filter_log_tmp = adply(all_filter_log,1,function(df) model(df))
n1=dim(all_filter_log)[2]+1
n2=dim(all_filter_log_tmp)[2]
all_result = all_filter_log_tmp[,n1:n2]


write.table(all_result ,file = paste(args[1],"sex_age_race",sep="_"),quote=FALSE,row.names = FALSE,col.names = FALSE,sep="\t")

