
options(stringsAsFactors=F)
library(survival)
library("plyr")

model <- function(df){

        df_t = as.data.frame(t(df))
        gene_ID = colnames(df_t)
        df_t$SRR_ID = rownames(df_t)
        colnames(df_t)[1]="gene"

        all=merge(all_info,df_t,by.x="sra_accession",by.y="SRR_ID")

        all=all[!is.na(as.numeric(all$gene)),]
        expression_threshold = median(all$gene)

        all$gene2 = all$gene
        all[as.numeric(all$gene)> expression_threshold,"gene2"] = "high_expression"
        all[as.numeric(all$gene)<= expression_threshold,"gene2"] = "low_expression"


        diff_model = tryCatch(survdiff(Surv(survival_time, Is_dead)~ gene2, all), error=function(e) NULL)
        if(!is.null(diff_model)){
                pvalue=pchisq(diff_model$chisq, length(diff_model$n)-1, lower.tail = FALSE)
                n_high_exp = as.numeric(diff_model$n[1])
                n_low_exp = as.numeric(diff_model$n[2])
                result = data.frame(transcript_ID=gene_ID,pvalue=pvalue,n_high_exp=n_high_exp,n_low_exp=n_low_exp)
        }
        if(is.null(diff_model)){
                result = data.frame(transcript_ID=gene_ID,pvalue=NA,n_high_exp=NA,n_low_exp=NA)
        }
        return(result)
}



#read file

all_info = read.table("Whole_TCGA_survival_stage",sep="\t",header=T)

args <- commandArgs(trailingOnly = TRUE)
header = read.table("header",sep="\t",header=F,check.names=F)
all_FPKM_tissue_individual = read.table(args[1],sep="\t",header=F,check.names=F)
colnames(all_FPKM_tissue_individual) = as.character(header[,])

t1=sub("Coverage_", "",colnames(all_FPKM_tissue_individual))
t2=gsub("\\.", "-",t1)
t3=sub(":.*", "",t2)
colnames(all_FPKM_tissue_individual)=t3

######extract tissue samples of interest
tissue = args[2]

sample = all_info[all_info$SMTS==tissue,"sra_accession"]
#some of the samples are downloaded unsuccessfully

test = sample %in% colnames(all_FPKM_tissue_individual)
select_FPKM = all_FPKM_tissue_individual[,c("t_name",sample[which(test==TRUE)])]
#condition=colnames(select_FPKM)[-1]
#all_filter = select_FPKM[rowSums(select_FPKM[,-1]<0.1)!=dim(select_FPKM)[2]-1,] #filter transcripts not expressed in all of the tumor samples
all_filter = select_FPKM

rownames(all_filter)=all_filter$t_name

all_filter = all_filter[,-1]

all_filter[all_filter<0.1] <- 0




#call the function

all_filter_log_tmp = adply(all_filter,1,function(df) model(df))
n1=dim(all_filter)[2]+1
n2=dim(all_filter_log_tmp)[2]
all_result = all_filter_log_tmp[,n1:n2]



write.table(all_result ,file = paste(args[1],args[2],"K_M_gene",sep="_"),quote=FALSE,row.names = FALSE,col.names = FALSE,sep="\t")
