
options(stringsAsFactors=F)
library(survival)
library("plyr")

model <- function(df){

df_t = as.data.frame(t(df))
gene_ID = colnames(df_t)
df_t$SRR_ID = rownames(df_t)
colnames(df_t)[1]="gene"
all=merge(all_info,df_t,by.x="sra_accession",by.y="SRR_ID")

#strata age

min_age = as.numeric(summary(all$AGE)[1])
one_qu_age = as.numeric(summary(all$AGE)[2])
median_age = as.numeric(summary(all$AGE)[3])
three_qu_age = as.numeric(summary(all$AGE)[5])
max_age = as.numeric(summary(all$AGE)[6])


all$AGE_2 = all$AGE
all$AGE_2 = ifelse(is.na(all$AGE),0,all$AGE)
all[all$AGE_2 >= min_age & all$AGE_2 <=one_qu_age, "AGE_2"] = 1 #Min. 1st Qu.
all[all$AGE_2 > one_qu_age & all$AGE_2 <=median_age, "AGE_2"] = 2 #Median
all[all$AGE_2 > median_age & all$AGE_2 <=three_qu_age, "AGE_2"] = 3 #3rd Qu.
all[all$AGE_2 > three_qu_age & all$AGE_2 <=max_age, "AGE_2"] = 4 #Max.
all[all$AGE_2==0,"AGE_2"] = NA
model_cancer = tryCatch(coxph(Surv(survival_time, Is_dead) ~  gene + RACE + strata(AGE_2), data=all, na.action=na.omit), error=function(e) NULL)

if(!is.null(model_cancer))
{
        test_model = cox.zph(model_cancer)
        gene_coef=summary(model_cancer)$coefficients["gene","coef"]
        gene_exp_coef=summary(model_cancer)$coefficients["gene","exp(coef)"]
        gene_p=summary(model_cancer)$coefficients["gene","Pr(>|z|)"]
        gene_test_p = test_model$table["gene","p"]

        RACE_coef=summary(model_cancer)$coefficients["RACE","coef"]
        RACE_exp_coef=summary(model_cancer)$coefficients["RACE","exp(coef)"]
        RACE_p=summary(model_cancer)$coefficients["RACE","Pr(>|z|)"]
        RACE_test_p = test_model$table["RACE","p"]

        result = data.frame(transcript_ID=gene_ID,gene_coef=gene_coef,gene_exp_coef=gene_exp_coef,gene_p=gene_p,gene_test_p=gene_test_p,
        RACE_coef=RACE_coef,RACE_exp_coef=RACE_exp_coef,RACE_p=RACE_p,RACE_test_p=RACE_test_p)

}
if(is.null(model_cancer))
        result = data.frame(transcript_ID=gene_ID,gene_coef=0,gene_exp_coef=0,gene_p=10000,gene_test_p=10000,
        RACE_coef=0,RACE_exp_coef=0,RACE_p=10000,RACE_test_p=10000)


return(result)
}

#read file

all_info = read.table("Whole_TCGA_survival_stage",sep="\t",header=T)

args <- commandArgs(trailingOnly = TRUE)
header = read.table("header",sep="\t",header=F,check.names=F)
all_FPKM_tissue_individual = read.table(args[1],sep="\t",header=F,check.names=F)
colnames(all_FPKM_tissue_individual) = as.character(header[,])

t1=sub("Coverage_", "",colnames(all_FPKM_tissue_individual))
t2=gsub("\\.", "-",t1)
t3=sub(":.*", "",t2)
colnames(all_FPKM_tissue_individual)=t3

######extract tissue samples of interest
tissue = args[2]

sample = all_info[all_info$SMTS==tissue,"sra_accession"]

test = sample %in% colnames(all_FPKM_tissue_individual)
select_FPKM = all_FPKM_tissue_individual[,c("t_name",sample[which(test==TRUE)])]
condition=colnames(select_FPKM)[-1]

all_filter = select_FPKM

rownames(all_filter)=all_filter$t_name

all_filter = all_filter[,-1]
all_filter[all_filter<0.1] <- 0

all_filter_log=log(all_filter+1)

#call the function

all_filter_log_tmp = adply(all_filter_log,1,function(df) model(df))
n1=dim(all_filter_log)[2]+1
n2=dim(all_filter_log_tmp)[2]
all_result = all_filter_log_tmp[,n1:n2]



write.table(all_result ,file = paste(args[1],args[2],"survival_gene_strata_age",sep="_"),quote=FALSE,row.names = FALSE,col.names = FALSE,sep="\t")


