library( "stringr" )
library("nlme")
library("plyr")
options(stringsAsFactors=F)

model <- function(df){

df_t = as.data.frame(t(df))
gene_ID = colnames(df_t)
df_t$SRR_ID = rownames(df_t)
colnames(df_t)[1]="gene"

all=merge(all_info,df_t,by.x="sra_accession",by.y="SRR_ID")
all$STAGE = as.numeric(all$STAGE)

model_cancer = tryCatch(lme(fixed = gene ~ GENDER + RACE + STAGE + AGE, random = ~1|Individual_ID, control=lmeControl(opt = "optim",maxIter=500000,msMaxIter=500000),data = all,na.action=na.omit), error=function(e) NULL)

if(!is.null(model_cancer))
{
        p_value_cancer=summary(model_cancer)$tTable["STAGE","p-value"]
        coeff_cancer=summary(model_cancer)$tTable["STAGE","Value"]

        p_value_GENDER=summary(model_cancer)$tTable["GENDER","p-value"]
        coeff_GENDER=summary(model_cancer)$tTable["GENDER","Value"]

        p_value_RACE=summary(model_cancer)$tTable["RACE","p-value"]
        coeff_RACE=summary(model_cancer)$tTable["RACE","Value"]

        p_value_AGE=summary(model_cancer)$tTable["AGE","p-value"]
        coeff_AGE=summary(model_cancer)$tTable["AGE","Value"]

        result = data.frame(transcript_ID=gene_ID,p_value_cancer=p_value_cancer,coeff_cancer=coeff_cancer,p_value_GENDER=p_value_GENDER,coeff_GENDER=coeff_GENDER,p_value_RACE=p_value_RACE,coeff_RACE=coeff_RACE, p_value_AGE=p_value_AGE,coeff_AGE=coeff_AGE)
}

if(is.null(model_cancer))
        result = data.frame(transcript_ID=gene_ID,p_value_cancer=10000,coeff_cancer=0,p_value_GENDER=10000,coeff_GENDER=0,p_value_RACE=10000,coeff_RACE=0,p_value_AGE=10000,coeff_AGE=0)


return(result)
}

#read file
all_info = read.table("Whole_TCGA_survival_stage",sep="\t",header=T)
all_info$STAGE = all_info$stage2
all_info[all_info$stage2 %in% "I","STAGE"]=1
all_info[all_info$stage2 %in% "II","STAGE"]=2
all_info[all_info$stage2 %in% "III","STAGE"]=3
all_info[all_info$stage2 %in% "IV","STAGE"]=4


args <- commandArgs(trailingOnly = TRUE)
header = read.table("header",sep="\t",header=F,check.names=F)
all_FPKM_tissue_individual = read.table(args[1],sep="\t",header=F,check.names=F)
colnames(all_FPKM_tissue_individual) = as.character(header[,])

t1=sub("Coverage_", "",colnames(all_FPKM_tissue_individual))
t2=gsub("\\.", "-",t1)
t3=sub(":.*", "",t2)
colnames(all_FPKM_tissue_individual)=t3

######extract tissue samples of interest
tissue = args[2]

sample = all_info[all_info$SMTS==tissue,"sra_accession"]
#some of the samples are downloaded unsuccessfully

test = sample %in% colnames(all_FPKM_tissue_individual)
select_FPKM = all_FPKM_tissue_individual[,c("t_name",sample[which(test==TRUE)])]
condition=colnames(select_FPKM)[-1]

all_filter = select_FPKM

rownames(all_filter)=all_filter$t_name

all_filter = all_filter[,-1]
all_filter[all_filter<0.1] <- 0

all_filter_log=log(all_filter+1)

#call the function

all_filter_log_tmp = adply(all_filter_log,1,function(df) model(df))
n1=dim(all_filter_log)[2]+1
n2=dim(all_filter_log_tmp)[2]
all_result = all_filter_log_tmp[,n1:n2]
write.table(all_result ,file = paste(args[1],args[2],"stage_gene",sep="_"),quote=FALSE,row.names = FALSE,col.names = FALSE,sep="\t")

